%define srcname	LibreCAD

# comment out if not pre release
%define prel	rc4

# rel for bumping
%define rel	1

%define dxfrw_includedir %(pkg-config --cflags-only-I libdxfrw | sed 's|-I||g')

# exclude plugin .so from provides
%global __provides_exclude_from %{_libdir}/librecad/plugins/.*\\.so

Name:		librecad
Summary:	An generic 2D CAD program
Version:	2.2.0
Release:	%mkrel 0.1
Group:		Graphics
License:	GPLv2
URL:		https://www.librecad.org/
Source0:	https://github.com/LibreCAD/LibreCAD/archive/%{version}%{?prel:-%prel}/%{srcname}-%{version}%{?prel:-%prel}.tar.xz
# Originally from Fedora:
Patch0:		LibreCAD-2.2.0-rc3-use-system-shapelib.patch
Patch1:		LibreCAD-2.1.1-use-system-libdxfrw.patch
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(muparser)
BuildRequires:	pkgconfig(shapelib)
BuildRequires:	pkgconfig(libdxfrw)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	qttools5

Obsoletes: librecad-doc


%description
LibreCAD is a Qt5 application to design 2D cad drawing based on the community
edition of QCad.

%files
%{_bindir}
%{_datadir}
%{_libdir}
%doc %{_datadir}/doc/%{name}/html/
%dir %{_datadir}/doc/%{name}

#------------------------------------------------------------------------------

%prep
%setup -qn %{srcname}-%{version}%{?prel:-%prel}
%apply_patches

echo 'MUPARSER_DIR = %{_prefix}' >> settings_linux.pro
echo 'BOOST_DIR = %{_includedir}' >> settings_linux.pro
echo 'BOOST_LIBDIR = %{_libdir}' >> settings_linux.pro

sed -i 's|$${DXFRW_INCLUDEDIR}|%{dxfrw_includedir}|g' librecad/src/src.pro

# drop bundled libs and use system ones
rm -rf plugins/importshp/shapelib
rm -rf libraries/libdxfrw
rm -rf libraries/muparser

# fix version info
sed -i -e 's/^LC_VERSION=\".*\"/LC_VERSION=\"%{version}%{?prel:-%prel}\"/' librecad/src/src.pro

%build
export PATH=%_qt5_bindir:$PATH
%qmake_qt5 librecad.pro
%make_build

%install
# Let's create the directory structure
mkdir -p %{buildroot}%{_datadir}/%{name}/{fonts,patterns,qm,library/misc,library/templates,doc}
mkdir -p %{buildroot}%{_datadir}/doc/%{name}/html/{classref/html/,img,imgs}
mkdir -p %{buildroot}%{_datadir}/applications/
mkdir -p %{buildroot}%{_libdir}/%{name}/plugins

# Now install all files
install -Dm 0755 unix/%{name} %{buildroot}/%{_bindir}/%{name}
install -Dm 0644 librecad/res/main/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -m 0644 unix/resources/patterns/*.dxf %{buildroot}%{_datadir}/%{name}/patterns/
install -m 0644 unix/resources/fonts/* %{buildroot}%{_datadir}/%{name}/fonts/
install -m 0644 unix/resources/library/misc/* %{buildroot}%{_datadir}/%{name}/library/misc/
install -m 0644 unix/resources/library/templates/* %{buildroot}%{_datadir}/%{name}/library/templates/
install -m 0644 unix/resources/qm/*.qm %{buildroot}%{_datadir}/%{name}/qm/
install -m 0755 unix/resources/plugins/* %{buildroot}%{_libdir}/%{name}/plugins/

# Install documentation files
install -m 0644 librecad/support/doc/*.html %{buildroot}%{_datadir}/doc/%{name}/html/

# appdata
install -Dpm 0644 librecad/support/librecad.appdata.xml %{buildroot}%{_metainfodir}/%{name}.appdata.xml

# Create the desktop file
mkdir -p  %{buildroot}%{_datadir}/applications/
desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--add-category="Qt" \
	--remove-mime-type="image/vnd.dxf" \
	--add-mime-type="image/vnd.dxf" \
		desktop/librecad.desktop

install -m 0644 -D desktop/librecad.sharedmimeinfo %{buildroot}%{_datadir}/mime/packages/%{name}.xml


%changelog
* Thu Aug 04 2022 tex - 2.2.0-0.rc4.1pclos2022
- new version 2.2.0-rc4
